@@ -5,20 +5,35 @@ use std::{
 
 use cli::app::app;
 use git2::{Config, Repository};
+use miette::{IntoDiagnostic, Result};
 use mit_commit_message_lints::external::Git2;
 use mit_lint::Lint;
 
-use crate::errors::GitMitConfigError;
+use crate::errors::{
+    LibGit2::{DiscoverGitRepository, ReadConfigFromGitRepository, ReadUserConfigFromGit},
+    UnrecognisedLintCommand,
+};
 
 mod cli;
 mod cmd;
 mod errors;
 
-fn main() -> Result<(), GitMitConfigError> {
+fn main() -> Result<()> {
+    if env::var("DEBUG_PRETTY_ERRORS").is_ok() {
+        miette::set_hook(Box::new(|_| {
+            Box::new(
+                miette::MietteHandlerOpts::new()
+                    .force_graphical(true)
+                    .build(),
+            )
+        }))
+        .unwrap();
+    }
+
     let lint_names: Vec<&str> = Lint::all_lints().map(Lint::name).collect();
     let matches = app(&lint_names).get_matches();
 
-    let possible: Option<Result<(), GitMitConfigError>> = [
+    let possible: Option<Result<()>> = [
         cmd::author_example::run_on_match,
         cmd::author_set::run_on_match,
         cmd::author_generate::run_on_match,
@@ -37,20 +52,24 @@ fn main() -> Result<(), GitMitConfigError> {
         return response;
     };
 
-    Err(GitMitConfigError::UnrecognisedLintCommand)
+    Err(UnrecognisedLintCommand {}.into())
 }
 
-fn get_vcs(local: bool, current_dir: &Path) -> Result<Git2, GitMitConfigError> {
+fn get_vcs(local: bool, current_dir: &Path) -> Result<Git2> {
     let git_config = if local {
         Repository::discover(current_dir.to_path_buf())
-            .and_then(|repo: Repository| repo.config())?
+            .map_err(|source| DiscoverGitRepository { source })
+            .and_then(|repo: Repository| {
+                repo.config()
+                    .map_err(|source| ReadConfigFromGitRepository { source })
+            })?
     } else {
-        Config::open_default()?
+        Config::open_default().map_err(|source| ReadUserConfigFromGit { source })?
     };
 
     Ok(Git2::new(git_config))
 }
 
-fn current_dir() -> Result<PathBuf, GitMitConfigError> {
-    Ok(env::current_dir()?)
+fn current_dir() -> Result<PathBuf> {
+    env::current_dir().into_diagnostic()
 }
